@@ -302,6 +302,8 @@ def test_os_build_compare():
     assert not res
     res = utils.version_compare("1.10-4+deb11u1", 0, "*", None, "1.10-4+deb11u1")
     assert not res
+    res = utils.version_compare("1.15.0", 0, "*", None, "1.15.1-2ubuntu2.2")
+    assert res
 
 
 def test_parse_uri():
@@ -336,3 +338,23 @@ def test_convert_md_references():
         {"name": "Issue #60", "url": "https://github.com/tj/node-growl/issues/60"},
         {"name": "PR #61", "url": "https://github.com/tj/node-growl/pull/61"},
     ]
+
+
+def test_ubuntu_versions():
+    assert utils.checkEpoch("1:4.14-1.1+deb7u1build0.12.04.1")
+    assert utils.convert_to_semver("0.3.14-11ubuntu6")[0]
+    assert utils.convert_to_semver("1.4.9a-1ubuntu0.1")[0]
+    assert utils.convert_to_semver("20140405-0ubuntu1")[0]
+    assert utils.convert_to_semver("1.10+dfsg~beta1-2ubuntu0.7")[0]
+    assert utils.convert_to_semver("1.11.3+dfsg-3ubuntu2")[0]
+    assert utils.convert_to_semver("1.0.4cvs20051004-2")[0]
+    assert utils.convert_to_semver("7.0.0-0ubuntu45")[0]
+    assert utils.convert_to_semver("1.5.0+1.5.1cvs20051015-1ubuntu10")[0]
+    assert utils.convert_to_semver("1.2.8rel-1ubuntu3")[0]
+    assert utils.convert_to_semver("3.3.8really3.3.7-0ubuntu5.2")[0]
+    assert utils.convert_to_semver("1.5.0+1.5.1cvs20051015-1ubuntu10")[0]
+    assert utils.convert_to_semver("0.9.2+cvs.1.0.dev.2004.07.28-4ubuntu1")[0]
+    assert utils.convert_to_semver("8.1.2-0.20040524cvs-2")[0]
+    assert utils.convert_to_semver("6.2.4.5.dfsg1-0.14ubuntu0.1")[0]
+    assert utils.convert_to_semver("1.5.dfsg+1.5.0.13~prepatch070731-0ubuntu1")[0]
+    assert utils.convert_to_semver("01.03.00.99.svn.300-3")[0]
