@@ -50,7 +50,7 @@ def get(db_file=config.vdb_bin_file, index_file=config.vdb_bin_index):
     return {"db_file": db_file, "index_file": index_file}
 
 
-def store(db, datas):
+def store(db, datas, reindex=True):
     """Store data in the table
 
     :param table: Table instance
@@ -61,8 +61,11 @@ def store(db, datas):
         return None
     global index_data, vendor_index_data
     docs = storage.store(datas, db_file=db["db_file"], index_file=db["index_file"])
-    # Re-read the index
-    index_data, vendor_index_data = build_index(storage.stream_read(db["index_file"]))
+    if reindex:
+        # Re-read the index
+        index_data, vendor_index_data = build_index(
+            storage.stream_read(db["index_file"])
+        )
     return docs
 
 
