@@ -86,7 +86,7 @@ class NpmSource(NvdSource):
             if data and local_store:
                 self.store(data)
             return data
-        return None
+        return []
 
     def download_all(self, local_store=True):
         """Download all historic cve data"""
