@@ -112,9 +112,9 @@ class NvdSource(VulnerabilitySource):
         """Refresh CVE data"""
         return self.download_all()
 
-    def store(self, data):
+    def store(self, data, reindex=True):
         """Store data in the database"""
-        docs = dbLib.store(db, data)
+        docs = dbLib.store(db, data, reindex)
         return docs
 
     def bulk_search():
