@@ -18,7 +18,7 @@ def store(datas, db_file=config.vdb_bin_file, index_file=config.vdb_bin_index):
     index_list = []
     for data in data_list:
         if data["details"]["cpe_uri"]:
-            vendor, _, _ = parse_cpe(data["details"]["cpe_uri"])
+            vendor, _, _, cve_type = parse_cpe(data["details"]["cpe_uri"])
             if vendor:
                 index_list.append(
                     {
